@@ -7,7 +7,7 @@ summary: A simple PyTorch implementation/tutorial of AMSGrad optimizer.
 # AMSGrad
 
 This is a [PyTorch](https://pytorch.org) implementation of the paper
-[On the Convergence of Adam and Beyond](https://arxiv.org/abs/1904.09237).
+[On the Convergence of Adam and Beyond](https://papers.labml.ai/paper/1904.09237).
 
 We implement this as an extension to our [Adam optimizer implementation](adam.html).
 The implementation it self is really small since it's very similar to Adam.
