@@ -10,7 +10,7 @@ summary: >
 
 This module contains [PyTorch](https://pytorch.org/)
 implementations and explanations of original transformer
-from paper [Attention Is All You Need](https://arxiv.org/abs/1706.03762),
+from paper [Attention Is All You Need](https://papers.labml.ai/paper/1706.03762),
 and derivatives and enhancements of it.
 
 * [Multi-head attention](mha.html)
@@ -34,34 +34,34 @@ This is an implementation of GPT-2 architecture.
 ## [GLU Variants](glu_variants/simple.html)
 
 This is an implementation of the paper
-[GLU Variants Improve Transformer](https://arxiv.org/abs/2002.05202).
+[GLU Variants Improve Transformer](https://papers.labml.ai/paper/2002.05202).
 
 ## [kNN-LM](knn/index.html)
 
 This is an implementation of the paper
-[Generalization through Memorization: Nearest Neighbor Language Models](https://arxiv.org/abs/1911.00172).
+[Generalization through Memorization: Nearest Neighbor Language Models](https://papers.labml.ai/paper/1911.00172).
 
 ## [Feedback Transformer](feedback/index.html)
 
 This is an implementation of the paper
-[Accessing Higher-level Representations in Sequential Transformers with Feedback Memory](https://arxiv.org/abs/2002.09402).
+[Accessing Higher-level Representations in Sequential Transformers with Feedback Memory](https://papers.labml.ai/paper/2002.09402).
 
 ## [Switch Transformer](switch/index.html)
 
 This is a miniature implementation of the paper
-[Switch Transformers: Scaling to Trillion Parameter Models with Simple and Efficient Sparsity](https://arxiv.org/abs/2101.03961).
+[Switch Transformers: Scaling to Trillion Parameter Models with Simple and Efficient Sparsity](https://papers.labml.ai/paper/2101.03961).
 Our implementation only has a few million parameters and doesn't do model parallel distributed training.
 It does single GPU training but we implement the concept of switching as described in the paper.
 
 ## [Fast Weights Transformer](fast_weights/index.html)
 
 This is an implementation of the paper
-[Linear Transformers Are Secretly Fast Weight Memory Systems in PyTorch](https://arxiv.org/abs/2102.11174).
+[Linear Transformers Are Secretly Fast Weight Memory Systems in PyTorch](https://papers.labml.ai/paper/2102.11174).
 
 ## [FNet: Mixing Tokens with Fourier Transforms](fnet/index.html)
 
 This is an implementation of the paper
-[FNet: Mixing Tokens with Fourier Transforms](https://arxiv.org/abs/2105.03824).
+[FNet: Mixing Tokens with Fourier Transforms](https://papers.labml.ai/paper/2105.03824).
 
 ## [Attention Free Transformer](aft/index.html)
 
@@ -71,7 +71,7 @@ This is an implementation of the paper
 ## [Masked Language Model](mlm/index.html)
 
 This is an implementation of Masked Language Model used for pre-training in paper
-[BERT: Pre-training of Deep Bidirectional Transformers for Language Understanding](https://arxiv.org/abs/1810.04805).
+[BERT: Pre-training of Deep Bidirectional Transformers for Language Understanding](https://papers.labml.ai/paper/1810.04805).
 
 ## [MLP-Mixer: An all-MLP Architecture for Vision](mlp_mixer/index.html)
 
@@ -86,7 +86,7 @@ This is an implementation of the paper
 ## [Vision Transformer (ViT)](vit/index.html)
 
 This is an implementation of the paper
-[An Image Is Worth 16x16 Words: Transformers For Image Recognition At Scale](https://arxiv.org/abs/2010.11929).
+[An Image Is Worth 16x16 Words: Transformers For Image Recognition At Scale](https://papers.labml.ai/paper/2010.11929).
 """
 
 from .configs import TransformerConfigs
